<?php
/**
 * Custom template tags for this theme.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package queue
 */

if ( ! function_exists( 'queue_return_template_part' ) ) :
/**
 * Return the output of get_template_part as a string.
 */
function queue_return_template_part($template_name, $part_name=null) {
    ob_start();
    get_template_part($template_name, $part_name);
    $var = ob_get_contents();
    ob_end_clean();
    return $var;
}
endif;

if ( ! function_exists( 'queue_paging_nav' ) ) :
/**
 * Display navigation to next/previous set of posts when applicable.
 */
function queue_paging_nav() {
	// Don't print empty markup if there's only one page.
	if ( $GLOBALS['wp_query']->max_num_pages < 2 ) {
		return;
	}

	?>
	<nav class="navigation paging-navigation" role="navigation">
		<h1 class="screen-reader-text"><?php _e( 'Posts navigation', 'queue' ); ?></h1>
		<div class="nav-links loud">

			<?php if ( get_previous_posts_link() ) : ?>
			<div class="nav-next"><?php previous_posts_link( __( '<span class="meta-nav">&larr;</span> Newer posts', 'queue' ) ); ?></div>
			<?php endif; ?>

			<?php if ( get_next_posts_link() ) : ?>
			<div class="nav-previous"><?php next_posts_link( __( 'Older posts <span class="meta-nav">&rarr;</span>', 'queue' ) ); ?></div>
			<?php endif; ?>

		</div><!-- .nav-links -->
	</nav><!-- .navigation -->
	<?php
}
endif;

if ( ! function_exists( 'queue_post_nav' ) ) :
/**
 * Display navigation to next/previous post when applicable.
 */
function queue_post_nav() {
	// Don't print empty markup if there's nowhere to navigate.
	$previouspost = ( is_attachment() ) ? get_post( get_post()->post_parent ) : get_adjacent_post( false, '', true );
	$nextpost     = get_adjacent_post( false, '', false );

	if ( ! $nextpost && ! $previouspost ) {
		return;
	}
	?>
	<nav class="navigation post-navigation clearfix" role="navigation">
		<h1 class="screen-reader-text"><?php _e( 'Post navigation', 'queue' ); ?></h1>
				<div class='half'>
				<?php

			if ($nextpost) {
				$nexttitle = apply_filters( 'the_title', $nextpost->post_title );
				$nexturl = get_permalink($nextpost);

				echo "
						<a href='$nexturl'>
							<span class='loud'>&#65513; Newer Article</span>
							<h1>$nexttitle</h1>
						</a>
				";
			}

			echo '
					</div>
					<div class="half textright">
			';
	
			if ($previouspost) {
				$previoustitle = apply_filters( 'the_title', $previouspost->post_title );
				$previousurl = get_permalink($previouspost);

				echo "
						<a href='$previousurl'>
							<span class='loud'>Older Article &#65515;</span>
							<h1>$previoustitle</h1>
						</a>
				";
			}
				?>
				</div>
	</nav><!-- .navigation -->
	<?php
}
endif;

if ( ! function_exists( 'queue_posted_on' ) ) :
/**
 * Prints HTML with meta information for the current post-date/time and author.
 */
function queue_posted_on() {
	$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
	if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
		$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time>';
	}

	$time_string = sprintf( $time_string,
		esc_attr( get_the_date( 'c' ) ),
		esc_html( get_the_date() )
	);

	$posted_on = sprintf(
		_x( 'Posted on %s', 'post date', 'queue' ),
		'<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>'
	);

	$byline = sprintf(
		_x( 'by %s', 'post author', 'queue' ),
		'<span class="author vcard"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a>,</span> '
	);

	echo '<span class="byline"> ' . $byline . '</span><span class="posted-on">' . $posted_on . '</span>';

}
endif;

if ( ! function_exists( 'queue_entry_footer' ) ) :
/**
 * Prints HTML with meta information for the categories, tags and comments.
 */
function queue_entry_footer() {
	// Hide category and tag text for pages.
	if ( 'post' == get_post_type() ) {
		/* translators: used between list items, there is a space after the comma */
		$categories_list = get_the_category_list( __( ', ', 'queue' ) );
		if ( $categories_list && queue_categorized_blog() ) {
			printf( '<span class="cat-links">' . __( 'Posted in %1$s', 'queue' ) . '</span>', $categories_list );
		}

		/* translators: used between list items, there is a space after the comma */
		$tags_list = get_the_tag_list( '', __( ', ', 'queue' ) );
		if ( $tags_list ) {
			printf( '<span class="tags-links">' . __( 'Tagged %1$s', 'queue' ) . '</span>', $tags_list );
		}
	}

	if ( ! is_single() && ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
		echo '<span class="comments-link">';
		comments_popup_link( __( 'Leave a comment', 'queue' ), __( '1 Comment', 'queue' ), __( '% Comments', 'queue' ) );
		echo '</span>';
	}
}
endif;

/**
 * Returns true if a blog has more than 1 category.
 *
 * @return bool
 */
function queue_categorized_blog() {
	if ( false === ( $all_the_cool_cats = get_transient( 'queue_categories' ) ) ) {
		// Create an array of all the categories that are attached to posts.
		$all_the_cool_cats = get_categories( array(
			'fields'     => 'ids',
			'hide_empty' => 1,

			// We only need to know if there is more than one category.
			'number'     => 2,
		) );

		// Count the number of categories that are attached to the posts.
		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'queue_categories', $all_the_cool_cats );
	}

	if ( $all_the_cool_cats > 1 ) {
		// This blog has more than 1 category so queue_categorized_blog should return true.
		return true;
	} else {
		// This blog has only 1 category so queue_categorized_blog should return false.
		return false;
	}
}

/**
 * Flush out the transients used in queue_categorized_blog.
 */
function queue_category_transient_flusher() {
	// Like, beat it. Dig?
	delete_transient( 'queue_categories' );
}
add_action( 'edit_category', 'queue_category_transient_flusher' );
add_action( 'save_post',     'queue_category_transient_flusher' );
